@@ -44,7 +44,7 @@ if (!$parent_album_id) {
 
 try {
     $selection=new selection($_SESSION, array(
-        "coverphoto"    => "album.php?_action=update&amp;album_id=" . $album->getId() . "&amp;coverphoto=",
+        "coverphoto"    => "album.php?_action=coverphoto&amp;album_id=" . $album->getId() . "&amp;coverphoto=",
         "return"        => "_return=albums.php&amp;_qs=parent_album_id=" . $album->getId()
     ));
 } catch (photoNoSelectionException $e) {
@@ -97,12 +97,12 @@ $actionlinks=array();
 
 if ($user->canEditOrganizers()) {
     $actionlinks=array(
-        translate("new") => "album.php?_action=new&amp;parent_album_id=" . (int) $album->getId(),
         translate("edit") => "album.php?_action=edit&amp;album_id=" . (int) $album->getId(),
+        translate("new") => "album.php?_action=new&amp;parent_album_id=" . (int) $album->getId(),
+        translate("delete") => "album.php?_action=delete&amp;album_id=" . (int) $album->getId()
     );
     if ($album->get("coverphoto")) {
-        $actionlinks["unset coverphoto"]="album.php?_action=update&amp;album_id=" . (int) $album->getId() .
-            "&amp;coverphoto=NULL";
+        $actionlinks["unset coverphoto"]="album.php?_action=unsetcoverphoto&amp;album_id=" . (int) $album->getId();
     }
 }
 
