@@ -54,6 +54,11 @@ abstract class controller {
      */
     public function __construct(request $request) {
         $this->request=$request;
+
+        if (isset($this->request["_return"])) {
+            $this->redirect=$this->request["_return"] . "?" . $this->request->getReturnQueryString();
+        }
+
     }
 
     /**
