@@ -475,7 +475,7 @@ class person extends zophTable implements Organizer {
                 // 3 or more, assume first two are first, middle, rest is last
                 $this->set("first_name", array_shift($name_array));
                 $this->set("middle_name", array_shift($name_array));
-                $this->set("last_name", implode($name_array, " "));
+                $this->set("last_name", implode(" ", $name_array));
                 break;
             }
         }
