@@ -67,7 +67,7 @@ class photo extends zophTable {
 
     /** @var photographer Photographer of this photo*/
     public $photographer;
-    /** @var location Location where this photo was taken */
+    /** @var place Location where this photo was taken */
     public $location;
 
     /**
@@ -220,6 +220,9 @@ class photo extends zophTable {
         );
     }
 
+    /**
+     * Update photo object in the db
+     */
     public function update() {
         if (empty($this->get("time_corr"))) {
             $this->set("time_corr", 0);
@@ -227,6 +230,9 @@ class photo extends zophTable {
         return parent::update();
     }
 
+    /**
+     * Insert new photo object in the db
+     */
     public function insert() {
         if (empty($this->get("time_corr"))) {
             $this->set("time_corr", 0);
@@ -293,6 +299,24 @@ class photo extends zophTable {
         }
     }
 
+    /**
+     * Determine whether a specific user has "write" rights
+     * on this photo
+     * @param user The user to check
+     * @return bool is writable
+     */
+    public function isWritableBy(user $user) {
+        if ($user->isAdmin()) {
+            return true;
+        } else {
+            $perm = $user->getPhotoPermissions($this);
+            if ($perm instanceof permissions) {
+                return (bool) $perm->get("writable");
+            }
+        }
+        return false;
+    }
+
     /**
      * Updates the photo's dimensions and filesize
      */
@@ -331,6 +355,14 @@ class photo extends zophTable {
         return (int) $result["pos"];
     }
 
+    /**
+     * Get the file name of this photo
+     * @return string file name
+     */
+    public function getName() {
+        return $this->get("name");
+    }
+
     /**
      * Add this photo to album, category, person or location
      * @param organizer album, category, person or location
@@ -439,7 +471,7 @@ class photo extends zophTable {
                 $links[]=$person->getLink(0);
             }
         }
-        return implode(", ", $links);
+        return $links;
     }
 
     /**
@@ -503,7 +535,7 @@ class photo extends zophTable {
                         $file->checkCopy();
                     }
                 }
-            } catch (FileException $e) {
+            } catch (fileException $e) {
                 throw $e;
             }
             // We run this loop twice, because we only want to move/copy the
@@ -517,7 +549,7 @@ class photo extends zophTable {
                     }
                     $new->chmod();
                 }
-            } catch (FileException $e) {
+            } catch (fileException $e) {
                 throw $e;
             }
             $this->set("name", $newname);
@@ -573,7 +605,7 @@ class photo extends zophTable {
 
     /**
      * Get the URL to an image
-     * @param string "mid" or "thumb"
+     * @param string|null "mid" or "thumb"
      * @return string URL
      */
     public function getURL($type = null) {
@@ -588,7 +620,7 @@ class photo extends zophTable {
 
     /**
      * Create an img tag for this photo
-     * @param type type of image (thumb, mid or null for full)
+     * @param string type type of image (thumb, mid or null for full)
      * @return block template block for image tag
      */
     public function getImageTag($type = null) {
@@ -797,11 +829,11 @@ class photo extends zophTable {
         $dir=dirname($new_image);
 
         if (!is_writable($dir)) {
-            throw new FileDirNotWritableException("Directory not writable: " . $dir);
+            throw new fileDirNotWritableException("Directory not writable: " . $dir);
         }
 
         if (!imagejpeg($img_dst, $new_image)) {
-            throw new PhotoThumbCreationFailedException("Could not create " . $prefix . " image");
+            throw new photoThumbCreationFailedException("Could not create " . $prefix . " image");
         }
 
         imagedestroy($img_dst);
@@ -839,7 +871,7 @@ class photo extends zophTable {
             // is always preserved.
             if (!file_exists($dir . $backup_name)) {
                 if (!@copy($dir . $name, $dir . $backup_name)) {
-                    throw new FileCopyFailedException(
+                    throw new fileCopyFailedException(
                         sprintf(translate("Could not copy %s to %s."), $name, $backup_name));
                 }
             }
@@ -848,7 +880,7 @@ class photo extends zophTable {
         // make a system call to convert or jpegtran to do the rotation.
         foreach ($images as $file => $tmp_file) {
             if (!file_exists($file)) {
-                throw new FileNotFoundException("Could not find " . $file);
+                throw new fileNotFoundException("Could not find " . $file);
             }
             switch (conf::get("rotate.command")) {
             case "jpegtran":
@@ -867,7 +899,7 @@ class photo extends zophTable {
             $output = system($cmd);
 
             if ($output) { // error
-                throw new ZophException(translate("An error occurred. ") . $output);
+                throw new zophException(translate("An error occurred. ") . $output);
             }
 
             rename($tmp_file, $file);
@@ -939,34 +971,18 @@ class photo extends zophTable {
      */
     public function getCameraDisplayArray() {
         return array(
-            translate("camera make") => $this->get("camera_make"),
-            translate("camera model") => $this->get("camera_model"),
-            translate("flash used") => $this->get("flash_used"),
-            translate("focal length") => $this->get("focal_length"),
-            translate("exposure") => $this->get("exposure"),
-            translate("aperture") => $this->get("aperture"),
-            translate("compression") => $this->get("compression"),
-            translate("iso equiv") => $this->get("iso_equiv"),
-            translate("metering mode") => $this->get("metering_mode"),
-            translate("focus distance") => $this->get("focus_dist"),
-            translate("ccd width") => $this->get("ccd_width"),
-            translate("comment") => $this->get("comment"));
-    }
-
-    /**
-     * Get array of form fields to edit this photo
-     * @return array of form fields
-     */
-    public function getEditArray() {
-        return array(
-            "Title" => create_text_input("title", $this->title),
-            "Date" => create_text_input("date", $this->date_taken),
-            "Photographer" => create_text_input("photographer",
-                $this->photographer ? $this->photographer->getName() : ""),
-            "Location" => create_text_input("location",
-                $this->location ? $this->location->getName() : ""),
-            "View" => create_text_input("view", $this->view),
-            "Level" => create_text_input("level", $this->level, 4, 2));
+            "camera make" => $this->get("camera_make"),
+            "camera model" => $this->get("camera_model"),
+            "flash used" => $this->get("flash_used"),
+            "focal length" => $this->get("focal_length"),
+            "exposure" => $this->get("exposure"),
+            "aperture" => $this->get("aperture"),
+            "compression" => $this->get("compression"),
+            "iso equiv" => $this->get("iso_equiv"),
+            "metering mode" => $this->get("metering_mode"),
+            "focus distance" => $this->get("focus_dist"),
+            "ccd width" => $this->get("ccd_width"),
+            "comment" => $this->get("comment"));
     }
 
     /**
@@ -1338,7 +1354,7 @@ class photo extends zophTable {
         if (file_exists($file)) {
             return sha1_file($file);
         } else {
-            throw new FileNotFoundException("File not found:" . $file);
+            throw new fileNotFoundException("File not found:" . $file);
         }
     }
 
@@ -1400,7 +1416,7 @@ class photo extends zophTable {
             $int_maxdist=5, $entity="km", $int_maxtime=600) {
 
         date_default_timezone_set("UTC");
-        $datetime=$this->getUTCTime();
+        $datetime=$this->getUTCtime();
         $utc=strtotime($datetime[0] . " " . $datetime[1]);
 
         $qry=new select(array("pt" => "point"));
@@ -1509,68 +1525,6 @@ class photo extends zophTable {
         return $clean_subset;
     }
 
-
-
-    /**
-     * Take an array of photos and remove photos with no valid timezone
-     *
-     * This function is needed for geotagging: for photos without a valid
-     * timezone it is not possible to determine the UTC time, needed for geotagging.
-     * @param array Array of photos
-     * @return array Array of photos with a valid timezone
-     */
-    public static function removePhotosWithNoValidTZ(array $photos) {
-
-        $gphotos=array();
-        log::msg("Number of photos before valid timezone check: " .
-            count($photos), log::DEBUG, log::GEOTAG);
-
-        foreach ($photos as $photo) {
-            $photo->lookup();
-            $loc=$photo->location;
-            if (get_class($loc)=="place") {
-                $tz=$loc->get("timezone");
-                if (TimeZone::validate($tz)) {
-                    $gphotos[]=$photo;
-                }
-            }
-        }
-        log::msg("Number of photos after valid timezone check: " . count($gphotos),
-            log::DEBUG, log::GEOTAG);
-        return $gphotos;
-    }
-
-    /**
-     * Take an array of photos and remove photos that already have lat/lon
-     * information set.
-     *
-     * This function is needed for geotagging, so photos that have lat/lon
-     * manually set will not be overwritten
-     * @param array Array of photos
-     * @return array Array of photos with no lat/lon info
-     */
-    public static function removePhotosWithLatLon($photos) {
-        $gphotos=array();
-        log::msg("Number of photos before overwrite check: " . count($photos),
-            log::DEBUG, log::GEOTAG);
-        foreach ($photos as $photo) {
-            $photo->lookup();
-            if (!($photo->get("lat") or $photo->get("lon"))) {
-                $gphotos[]=$photo;
-            }
-        }
-        log::msg("Number of photos after overwrite check: " . count($gphotos),
-            log::DEBUG, log::GEOTAG);
-        return $gphotos;
-    }
-
-    /**
-     * Find a photo from a SHA1-hashed string
-     * @param string hash
-     * @param type of hash: file = filehash, full/mid salted has for sharing of photos
-     * @return photo found photo
-     */
-
     public static function getFromHash($hash, $type="file") {
 
         $qry=new select(array("p" => "photos"));
@@ -1600,7 +1554,7 @@ class photo extends zophTable {
         if (is_array($photos) && sizeof($photos) > 0) {
             return $photos[0];
         } else {
-            throw new PhotoNotFoundException("Could not find photo from hash");
+            throw new photoNotFoundException("Could not find photo from hash");
         }
     }
 
@@ -1668,7 +1622,7 @@ class photo extends zophTable {
 
     /**
      * Get filesize for a set of photos
-     * @param array Array of photos
+     * @param collection photos
      * @return int size in bytes
      */
     public static function getFilesize(collection $photos) {
