@@ -37,6 +37,19 @@ use user;
  */
 class collection extends \generic\collection {
 
+    /**
+     * Get an array of all the photo ids in this collection
+     * @return array ids
+     */
+    public function getIds() {
+        $ids = array();
+        foreach ($this->items as $photo) {
+            $ids[] = $photo->getId();
+        }
+        return $ids;
+
+    }
+
     /**
      * Remove all photos that have no valid timezone
      *
@@ -148,5 +161,5 @@ class collection extends \generic\collection {
         $photos=photo::getRecordsFromQuery($search->getQuery());
         return static::createFromArray($photos, true);
     }
-
+    
 }
