@@ -92,8 +92,14 @@ class rating extends zophTable {
         } catch (PDOException $e) {
             log::msg("Rating recalculation failed", log::FATAL, log::DB);
         }
-        $avg = (round(100 * $row["average"])) / 100.0;
 
+        if($row === false) {
+            $avg = null;
+        } else {
+            $avg = (round(100 * $row["average"])) / 100.0;
+        }
+
+        // Not sure if this still needed
         if ($avg == 0) {
             $avg = null;
         }
