@@ -59,6 +59,9 @@ class request implements ArrayAccess {
              not called $request */
     private $requestVars;
 
+    /** @var queryString holds query string */
+    private $queryString;
+
     /**
      * Create object
      * @param array array of variables, can contain GET, POST and SERVER
@@ -72,6 +75,8 @@ class request implements ArrayAccess {
             }
         }
         $this->buildRequest();
+
+        $this->queryString = new queryString($this->getServerVar("QUERY_STRING"), $this["_qs"]);
     }
 
     /**
@@ -165,14 +170,14 @@ class request implements ArrayAccess {
      * Return the query string, urlencoded, it can be passed via an URL
      */
     public function getEncodedQueryString() {
-        return urlencode(htmlentities($this->getReturnQueryString()));
+        return $this->queryString->encode();
     }
 
     /**
      * Get the query string that was used to get to this page
      */
     public function getQueryString() {
-        return $this->getServerVar("QUERY_STRING");
+        return $this->queryString;
     }
 
     /**
@@ -184,7 +189,7 @@ class request implements ArrayAccess {
      * query string through this function.
      */
     public function getPassedQueryString() {
-        return $this["_qs"];
+        return $this->queryString->getPassed()->get();
     }
 
     /**
@@ -208,14 +213,7 @@ class request implements ArrayAccess {
      * clean the current query string, removing "_crumb" and "_action"
      */
     public function getReturnQueryString() {
-        $return_qs=$this->getPassedQueryString();
-        if (empty($return_qs)) {
-            $return_qs = $this->cleanQueryString(array(
-                "/_crumb=\d+&?/",
-                "/_action=\w+&?/"
-            ));
-        }
-        return $return_qs;
+        return $this->queryString->getReturn();
     }
 
     /**
@@ -231,6 +229,19 @@ class request implements ArrayAccess {
         }
     }
 
+    /**
+     * Get $_POST variables
+     * @param Variable to return
+     * @return mixed value
+     */
+    public function getPostVar($var) {
+        if (isset($this->post[$var])) {
+            return $this->post[$var];
+        } else {
+            return null;
+        }
+    }
+
     /**
      * Remove any params without values and operator params without corresponding
      * fields (e.g. _album_id-op when there is no _album_id).  This can be called
