@@ -66,6 +66,10 @@ case "place.php":
     $scripts[]="js/json.js";
     $scripts[]="js/locationLookup.js";
     break;
+case "slideshow.php":
+    $scripts[]="js/json.js";
+    $scripts[]="js/slideshow.js";
+    break;
 }
 
 if (conf::get("interface.autocomplete")) {
