@@ -482,7 +482,7 @@ ul.breadcrumbs li a {
 }
 
 /* Main page */
-.main, .page, div.map, div#selection, div.related  {
+.main, .page, div.map, div#selection, div.related, div.permissions  {
     background: <?= colorScheme::getColor("table_bg_color") ?>;
     font-size: medium;
     width: 100%;
@@ -498,7 +498,8 @@ ul.breadcrumbs li a {
 /* when both a 'page' and the normal view are together, fix the
    border radius and add a small margin */
 .main + .page,
-.page + .main {
+.page + .main,
+.main + .permissions {
     border-radius: 5px;
     margin-top: 10px;
 }
@@ -1237,6 +1238,257 @@ img.<?= MID_PREFIX ?> {
     display: block;
 }
 
+/* SLIDESHOW */
+
+div.main:fullscreen {
+    background-image: linear-gradient(rgba(0,0,0,90%), rgba(0,0,0,70%));
+    padding: 0;
+}
+
+img#butFullscreen {
+    position: relative;
+    float: right;
+    margin: 5px 10px;
+    width: 64px;
+    height: 64px;
+    background-image: url(<?= template::getImage("icons/fullscreen.png") ?>);
+    opacity: 0.1;
+    z-index: 50;
+}
+
+img#butFullscreen:hover {
+    opacity: 1;
+}
+
+div.main:fullscreen img#butFullscreen {
+    background-image: url(<?= template::getImage("icons/nofullscreen.png") ?>);
+}
+
+img.photo {
+    position: relative;
+    top: -75px;
+    width: 100%;
+    max-width: 100%;
+    max-height: 65vh;
+    object-fit: scale-down;
+    margin: 0 auto;
+    overflow: hidden;
+}
+
+div.main:fullscreen img.photo {
+    max-height: 100%;
+}
+
+div.slide-annotate {
+    padding: 15px;
+    position: relative;
+    margin: -10px;
+    width: 100%;
+    background-image: linear-gradient(rgba(0,0,0,0%), rgba(0,0,0,30%));
+    overflow: hidden;
+
+}
+
+div.main:fullscreen div.slide-annotate {
+    background-image: linear-gradient(270deg, rgba(0,0,0,0%), rgba(0,0,0,70%));
+    width: 300px;
+    height: 100%;
+    position: absolute;
+    top: 0;
+    left: 0;
+    color: white;
+    animation: seconds 3.0s forwards;
+    animation-iteration-count: 1;
+    animation-delay: 2s;
+    font-size: 20px;
+}
+
+@media only screen and (max-width: 1024px) {
+    div.main:fullscreen div.slide-annotate {
+        font-size:20px
+        width: 100px;
+    }
+}
+
+@keyframes seconds {
+  0% {
+    opacity: 1;
+  }
+  100% {
+    opacity: 0;
+    left: -200px;
+  }
+}
+
+div.main:fullscreen div.slide-annotate dl.exif {
+    opacity: 0.5;
+    font-size: 80%;
+}
+
+div.main:fullscreen div.slide-annotate dl.exif dt {
+    display: block;
+    float: left;
+    clear: left;
+}
+div.main:fullscreen div.slide-annotate dl.exif dd {
+    float: left;
+    display: block;
+}
+
+div.slide-annotate dl.exif {
+    font-size: 80%;
+    white-space: pre-wrap;
+    clear: both;
+}
+
+div.slide-annotate dl.exif dt, 
+div.slide-annotate dl.exif dd {
+    position: relative;
+    float: none;
+    display: inline-block;
+    z-index: 1;
+    box-shadow: 3px 3px 3px rgba(0,0,0, 0.4);
+    color: <?= colorScheme::getColor("text_color") ?>;
+    border: 1px solid <?= colorScheme::getColor("table_border_color") ?>;
+    font-weight: normal;
+    min-height: 0;
+    padding: 4px;
+    margin: 2px;
+    clear: none;
+    width: auto;
+}
+
+div.slide-annotate dl.exif dt {
+    background: <?= colorScheme::getColor("breadcrumb_bg_color") ?>;
+    border-radius: 4px 0 0 4px;
+    margin-right: 0;
+    border-right: none;
+}
+
+div.slide-annotate dl.exif dt::after {
+    content: ":";
+}
+
+div.slide-annotate dl.exif dd {
+    background: <?= colorScheme::getColor("title_bg_color") ?>;
+    border-radius: 0 4px 4px 0;
+    border-left: none;
+    margin-left: 0px;
+    z-index: 5;
+}
+
+h3.exif {
+    display: none;
+}
+
+div.main:fullscreen div.slide-annotate dl.photodata {
+    opacity: 0.9;
+    font-size: 80%;
+}
+
+div.main:fullscreen div.slide-annotate dl.photodata dd,
+div.main:fullscreen div.slide-annotate dl.photodata dt {
+}
+
+div.main:fullscreen div.slide-annotate dl.photodata dt.icon {
+	width: 2em;
+}
+
+dl.photodata {
+	width: 100%;
+}
+
+dl.photodata dd {
+	min-height: 2.5em;
+	line-height: 2.5em;
+}
+
+dl.photodata dt {
+}
+
+dt.icon {
+    float: left;
+    width: 3em;
+    height: 3em;
+
+    text-indent: 100%;
+    white-space: nowrap;
+    overflow: hidden;
+    background-repeat: no-repeat;
+    background-size: contain;
+}
+dt.filename {
+    background-image: url("<?= template::getImage("icons/photobig.png") ?>");
+}
+
+dt.title {
+    background-image: url("<?= template::getImage("icons/title.png") ?>");
+}
+
+dt.photographer {
+    background-image: url("<?= template::getImage("icons/photographer.png") ?>");
+}
+
+dt.datetime {
+    background-image: url("<?= template::getImage("icons/datetime.png") ?>");
+}
+
+dt.location {
+    background-image: url("<?= template::getImage("icons/location.png") ?>");
+}
+
+dt.album {
+    background-image: url("<?= template::getImage("icons/album.png") ?>");
+}
+
+dt.category {
+    background-image: url("<?= template::getImage("icons/category.png") ?>");
+}
+
+dt.people {
+    background-image: url("<?= template::getImage("icons/people.png") ?>");
+}
+ 
+ul#slide-categories,
+ul#slide-people,
+ul#slide-albums {
+    list-style: none;
+    overflow: hidden;
+    margin: 2px;
+    padding: 4px;
+}
+
+ul#slide-categories li,
+ul#slide-people li,
+ul#slide-albums li {
+    display: block;
+    float: left;
+    border: 1px solid <?= colorScheme::getColor("table_border_color") ?>;
+    padding: 5px 10px;
+    margin:  0 0.5em;
+    border-radius: 3px;
+    box-shadow: 3px 3px 3px rgba(0,0,0, 0.4);
+    font-size: 90%;
+    line-height: 1em;
+}
+
+ul#slide-categories li {
+    background: <?= colorScheme::getColor("title_bg_color") ?>;
+    color: <?= colorScheme::getColor("title_font_color") ?>;
+}
+
+ul#slide-albums li {
+    background: <?= colorScheme::getColor("page_bg_color") ?>;
+    color: <?= colorScheme::getColor("text_color") ?>;
+}
+
+ul#slide-people li {
+    background: <?= colorScheme::getColor("tab_bg_color") ?>;
+    color: <?= colorScheme::getColor("tab_font_color") ?>;
+}
+
+/* END SLIDESHOW */
+
 img.busy,
 img.waiting {
     margin-left: auto;
